Exception: DiasporaFederation::Discovery::InvalidData
- Inherits:
-
DiscoveryError
- Object
- RuntimeError
- DiscoveryError
- DiasporaFederation::Discovery::InvalidData
- Defined in:
- lib/diaspora_federation/discovery/exceptions.rb
Overview
Raised, if something is wrong with the webfinger data
- if the
webfinger_urlis missing or malformed in HostMeta.from_base_url or HostMeta.from_xml - if the parsed XML from WebFinger.from_xml is incomplete
- if the html passed to HCard.from_html in some way is malformed, invalid or incomplete.